@@ -12,8 +12,19 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+"""This module contains all predefined classes to configure mutation, i.e. how a
+genetic algorithm can improve the elements of its current population by an
+individual local search.
+
+This module uses the abstract factory pattern to allow encapsulated state and
+isolated optimisation runs. Implementations of `Mutation` create
+implementations of `Recombination`, that implement the actual functionality.
+
+"""
+
 
 from .mutation import Mutator, Mutation
 from .identity_mutation import IdentityMutator, IdentityMutation
 from .addition_mutation import AdditionMutator, AdditionMutation
-from .reverse_annealing_mutation import ReverseAnnealingMutator, ReverseAnnealingMutation
+from .sampler_mutation import SamplerMutator, SamplerMutation
+from .reverse_annealing_mutation import ReverseAnnealingMutation
