@@ -13,22 +13,31 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from dimod import SampleSet, BinaryQuadraticModel
+from dimod import SampleSet
 
 from .mutation import Mutator, Mutation
+from ..problem import ProblemType
 
 
-class IdentityMutator(Mutator):
-    """
-    Passes the input population without any changes.
+class IdentityMutator(Mutator[ProblemType]):
+    """Mutation by no mutation.
+
     """
     def mutate(self, population: SampleSet) -> SampleSet:
+        """Passes the input population without any changes.
+
+        """
         return population
 
 
-class IdentityMutation(Mutation):
+class IdentityMutation(Mutation[ProblemType]):
+    """Configuration of algorithm with no mutation.
+
+    Useful for writing test cases that just need some mutation.
+
     """
-    A factory that produces instances `IdentityMutation`.
-    """
-    def initialise(self, problem: BinaryQuadraticModel) -> Mutator:
-        return IdentityMutator()
+    def initialise(self, problem: ProblemType) -> Mutator[ProblemType]:
+        """Creates a problem independent `IdentityMutator[ProblemType]`.
+
+        """
+        return IdentityMutator[ProblemType]()
