@@ -12,9 +12,25 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+"""This module contains all predefined classes to configure recombination, i.e.
+how a genetic algorithm can improve its popultion quality by combining
+individuals. In fact, it is implements information exchange between solution
+candidates.
+
+This module uses the abstract factory pattern to allow encapsulated state and
+isolated optimisation runs. Implementations of `Recombination` create
+implementations of `Recombinator`, that implement the actual functionality.
+"""
 
 from .recombination import Recombinator, Recombination
 from .addition_recombination import AdditionRecombinator, AdditionRecombination
 from .identity_recombination import IdentityRecombination, IdentityRecombinator
 from .random_bits_recombination import RandomBitsRecombinator, RandomBitsRecombination
-from .random_cluster_recombination import RandomClusterRecombinator, RandomClusterRecombination
+from .random_cluster_recombination import (
+    RandomClusterRecombinator,
+    RandomClusterRecombination,
+)
+from .random_sections_recombination import (
+    RandomSectionsRecombinator,
+    RandomSectionsRecombination,
+)
