@@ -16,16 +16,28 @@
 from dimod import SampleSet, BinaryQuadraticModel
 
 from .recombination import Recombinator, Recombination
+from ..problem import ProblemType
 
 
-class IdentityRecombinator(Recombinator):
-    """
-    Passes the input population without any changes.
+class IdentityRecombinator(Recombinator[ProblemType]):
+    """Recombination by no recombination.
+
     """
     def recombine(self, population: SampleSet) -> SampleSet:
+        """Passes the input population without any changes.
+
+        """
         return population
 
 
-class IdentityRecombination(Recombination):
-    def initialise(self, problem: BinaryQuadraticModel) -> Recombinator:
-        return IdentityRecombinator()
+class IdentityRecombination(Recombination[ProblemType]):
+    """Configuration of algorithm with no recombination.
+
+    Useful for writing test cases that just need some recombination.
+
+    """
+    def initialise(self, problem: ProblemType) -> Recombinator[ProblemType]:
+        """Creates a problem independent `IdentityRecombinator[ProblemType]`.
+
+        """
+        return IdentityRecombinator[ProblemType]()
