@@ -13,20 +13,30 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from dimod import SampleSet, BinaryQuadraticModel
+from dimod import SampleSet
 
 from .selection import Selector, Selection
+from ..problem import ProblemType
+
+
+class IdentitySelector(Selector[ProblemType]):
+    """Selection by no selection.
 
-class IdentitySelector(Selector):
-    """
-    Passes the input population without any changes.
     """
     def select(self, population: SampleSet) -> SampleSet:
+        """Passes the input population without any changes.
+
+        """
         return population
 
-class IdentitySelection(Selection):
+class IdentitySelection(Selection[ProblemType]):
+    """Configuration of algorithm with no selection.
+
+    Useful for writing test cases that just need some selection.
+
     """
-    A factory that produces instances `IdentitySelection`.
-    """
-    def initialise(self, problem: BinaryQuadraticModel) -> Selector:
+    def initialise(self, problem: ProblemType) -> Selector[ProblemType]:
+        """Creates a problem independent `IdentitySelector[ProblemType]`.
+
+        """
         return IdentitySelector()
