@@ -12,7 +12,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+"""This module contains all predefined classes to configure startup, i.e. how
+the initial population of a genetic algorithm is created.
+
+A good starting population can decrease runtime performance, if the individuals
+are already good, and increase solution quality of it is diverse.
+
+"""
 
 from .startup import Startup
 from .random_startup import RandomStartup
 from .warm_startup import WarmStartup
+from .sampling_startup import SamplingStartup
