@@ -14,17 +14,26 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 from abc import ABC, abstractmethod
+from typing import Generic
 
-from dimod import SampleSet, BinaryQuadraticModel
+from dimod import SampleSet
+
+from ..problem import ProblemType
 
 
-class Startup(ABC):
-    """
-    Interface for creating the initial population.
+class Startup(Generic[ProblemType], ABC):
+    """Interface for creating the initial population.
     """
     @abstractmethod
-    def startup(self, problem: BinaryQuadraticModel) -> SampleSet:
+    def startup(self, problem: ProblemType) -> SampleSet:
+        """Creates a population.
+
+        Args:
+            problem (ProblemType): The problem for which a
+                population is created.
+
+        Returns:
+            A non-empty `dimod.SampleSet` that shares the same variable type and
+            amount of qubits with `problem`.
+
         """
-        Creates a **nonempty** population.
-        """
-        pass
